@@ -136,8 +136,8 @@ namespace Breeze
         {
 
             const QRectF iconRect( geometry().topLeft(), m_iconSize );
-            const QPixmap pixmap = decoration()->client().data()->icon().pixmap( m_iconSize );
-            painter->drawPixmap(iconRect.center() - QPoint(pixmap.width()/2, pixmap.height()/2)/pixmap.devicePixelRatio(), pixmap);
+            decoration()->client().data()->icon().paint(painter, iconRect.toRect());
+
 
         } else {
 
