@@ -48,10 +48,8 @@
 
 #include "breezewindowmanager.h"
 #include "breezepropertynames.h"
-#include "breezestyleconfigdata.h"
 #include "breezehelper.h"
 
-#include <QApplication>
 #include <QComboBox>
 #include <QDialog>
 #include <QDockWidget>
@@ -81,6 +79,12 @@
 #include <QWindow>
 #endif
 
+#if QT_VERSION >= 0x050000
+// needed to enable dragging from QQuickWindows
+#include <QQuickItem>
+#include <QQuickWindow>
+#endif
+
 #if BREEZE_HAVE_X11
 #include <QX11Info>
 #include <xcb/xcb.h>
@@ -89,8 +93,6 @@
 #include <NETRootInfo>
 #else
 #include <NETWM>
-#include <QQuickItem>
-#include <QQuickWindow>
 #endif
 
 #endif
@@ -103,6 +105,22 @@
 #include <KWayland/Client/seat.h>
 #endif
 
+namespace Util
+{
+    template<class T>
+        inline T makeT( std::initializer_list<typename T::key_type>&& reference )
+    {
+        #if QT_VERSION >= 0x050100
+        return T( std::move( reference ) );
+        #else
+        // for old QT versions there is no container constructor from initializer_list
+        T out;
+        for( auto&& value:std::move(reference) ) { out.insert( value ); }
+        return out;
+        #endif
+    }
+}
+
 namespace Breeze
 {
 
@@ -197,27 +215,13 @@ namespace Breeze
         private:
 
         //* parent
-        WindowManager* _parent;
+        WindowManager* _parent = nullptr;
 
     };
 
     //_____________________________________________________________
     WindowManager::WindowManager( QObject* parent ):
-        QObject( parent ),
-        _enabled( true ),
-        _useWMMoveResize( true ),
-        _dragMode( StyleConfigData::WD_FULL ),
-        _dragDistance( QApplication::startDragDistance() ),
-        _dragDelay( QApplication::startDragTime() ),
-        _dragAboutToStart( false ),
-        _dragInProgress( false ),
-        _locked( false ),
-        _cursorOverride( false )
-        #if BREEZE_HAVE_KWAYLAND
-        , _seat( Q_NULLPTR )
-        , _pointer( Q_NULLPTR )
-        , _waylandSerial( 0 )
-        #endif
+        QObject( parent )
     {
 
         // install application wise event filter
@@ -227,7 +231,7 @@ namespace Breeze
     }
 
     //_____________________________________________________________
-    void WindowManager::initialize( void )
+    void WindowManager::initialize()
     {
 
         setEnabled( StyleConfigData::windowDragMode() != StyleConfigData::WD_NONE );
@@ -248,23 +252,19 @@ namespace Breeze
     {
         #if BREEZE_HAVE_KWAYLAND
         if( !Helper::isWayland() ) return;
-
-        if( _seat ) {
-            // already initialized
-            return;
-        }
+        if( _seat )  return;
 
         using namespace KWayland::Client;
         auto connection = ConnectionThread::fromApplication( this );
-        if( !connection ) {
-            return;
-        }
-        Registry *registry = new Registry( this );
+        if( !connection ) return;
+
+        auto registry = new Registry( this );
         registry->create( connection );
         connect(registry, &Registry::interfacesAnnounced, this,
             [registry, this] {
                 const auto interface = registry->interface( Registry::Interface::Seat );
-                if( interface.name != 0 ) {
+                if( interface.name != 0 )
+                {
                     _seat = registry->createSeat( interface.name, interface.version, this );
                     connect(_seat, &Seat::hasPointerChanged, this, &WindowManager::waylandHasPointerChanged);
                 }
@@ -281,13 +281,13 @@ namespace Breeze
     {
         #if BREEZE_HAVE_KWAYLAND
         Q_ASSERT( _seat );
-        if( hasPointer ) {
-            if( !_pointer ) {
+        if( hasPointer )
+        {
+            if( !_pointer )
+            {
                 _pointer = _seat->createPointer(this);
                 connect(_pointer, &KWayland::Client::Pointer::buttonStateChanged, this,
-                    [this] (quint32 serial) {
-                        _waylandSerial = serial;
-                    }
+                    [this] (quint32 serial) { _waylandSerial = serial; }
                 );
             }
         } else {
@@ -319,39 +319,36 @@ namespace Breeze
 
     }
 
-#if !BREEZE_USE_KDE4
+    #if !BREEZE_USE_KDE4
+    //_____________________________________________________________
     void WindowManager::registerQuickItem( QQuickItem* item )
     {
         if ( !item ) return;
 
-        QQuickWindow *window = item->window();
-        if (window) {
-            QQuickItem *contentItem = window->contentItem();
+        if( auto window = item->window() )
+        {
+            auto contentItem = window->contentItem();
             contentItem->setAcceptedMouseButtons( Qt::LeftButton );
             contentItem->removeEventFilter( this );
             contentItem->installEventFilter( this );
         }
 
     }
-#endif
+    #endif
 
     //_____________________________________________________________
     void WindowManager::unregisterWidget( QWidget* widget )
-    {
-        if( widget )
-        { widget->removeEventFilter( this ); }
-    }
+    { if( widget ) widget->removeEventFilter( this ); }
 
     //_____________________________________________________________
-    void WindowManager::initializeWhiteList( void )
+    void WindowManager::initializeWhiteList()
     {
 
-        _whiteList.clear();
-
-        // add user specified whitelisted classnames
-        _whiteList.insert( ExceptionId( QStringLiteral( "MplayerWindow" ) ) );
-        _whiteList.insert( ExceptionId( QStringLiteral( "ViewSliders@kmix" ) ) );
-        _whiteList.insert( ExceptionId( QStringLiteral( "Sidebar_Widget@konqueror" ) ) );
+        _whiteList = Util::makeT<ExceptionSet>({
+            ExceptionId( QStringLiteral( "MplayerWindow" ) ),
+            ExceptionId( QStringLiteral( "ViewSliders@kmix" ) ),
+            ExceptionId( QStringLiteral( "Sidebar_Widget@konqueror" ) )
+        });
 
         foreach( const QString& exception, StyleConfigData::windowDragWhiteList() )
         {
@@ -362,13 +359,15 @@ namespace Breeze
     }
 
     //_____________________________________________________________
-    void WindowManager::initializeBlackList( void )
+    void WindowManager::initializeBlackList()
     {
 
-        _blackList.clear();
-        _blackList.insert( ExceptionId( QStringLiteral( "CustomTrackView@kdenlive" ) ) );
-        _blackList.insert( ExceptionId( QStringLiteral( "MuseScore" ) ) );
-        _blackList.insert( ExceptionId( QStringLiteral( "KGameCanvasWidget" ) ) );
+        _blackList = Util::makeT<ExceptionSet>({
+            ExceptionId( QStringLiteral( "CustomTrackView@kdenlive" ) ),
+            ExceptionId( QStringLiteral( "MuseScore" ) ),
+            ExceptionId( QStringLiteral( "KGameCanvasWidget" ) )
+        });
+
         foreach( const QString& exception, StyleConfigData::windowDragBlackList() )
         {
             ExceptionId id( exception );
@@ -391,17 +390,17 @@ namespace Breeze
 
             case QEvent::MouseMove:
             if ( object == _target.data()
-#if !BREEZE_USE_KDE4
+                #if !BREEZE_USE_KDE4
                 || object == _quickTarget.data()
-#endif
+                #endif
                ) return mouseMoveEvent( object, event );
             break;
 
             case QEvent::MouseButtonRelease:
             if ( _target
-#if !BREEZE_USE_KDE4
+                #if !BREEZE_USE_KDE4
                 || _quickTarget
-#endif
+                #endif
                ) return mouseReleaseEvent( object, event );
             break;
 
@@ -422,15 +421,13 @@ namespace Breeze
         {
 
             _dragTimer.stop();
-#if BREEZE_USE_KDE4
+            #if BREEZE_USE_KDE4
             if( _target )
             { startDrag( _target.data()->window(), _globalDragPoint ); }
-#else
-            if( _target )
-            { startDrag( _target.data()->window()->windowHandle(), _globalDragPoint ); }
-            else if( _quickTarget )
-            { startDrag( _quickTarget.data()->window(), _globalDragPoint ); }
-#endif
+            #else
+            if( _target ) startDrag( _target.data()->window()->windowHandle(), _globalDragPoint );
+            else if( _quickTarget ) startDrag( _quickTarget.data()->window(), _globalDragPoint );
+            #endif
 
         } else {
 
@@ -445,7 +442,7 @@ namespace Breeze
     {
 
         // cast event and check buttons/modifiers
-        QMouseEvent *mouseEvent = static_cast<QMouseEvent*>( event );
+        auto mouseEvent = static_cast<QMouseEvent*>( event );
         if( !( mouseEvent->modifiers() == Qt::NoModifier && mouseEvent->button() == Qt::LeftButton ) )
         { return false; }
 
@@ -453,10 +450,11 @@ namespace Breeze
         if( isLocked() ) return false;
         else setLocked( true );
 
-#if !BREEZE_USE_KDE4
+        #if !BREEZE_USE_KDE4
         // check QQuickItem - we can immediately start drag, because QQuickWindow's contentItem
         // only receives mouse events that weren't handled by children
-        if ( QQuickItem *item = qobject_cast<QQuickItem*>( object ) ) {
+        if( auto item = qobject_cast<QQuickItem*>( object ) )
+        {
             _quickTarget = item;
             _dragPoint = mouseEvent->pos();
             _globalDragPoint = mouseEvent->globalPos();
@@ -466,17 +464,17 @@ namespace Breeze
 
             return true;
         }
-#endif
+        #endif
 
         // cast to widget
-        QWidget *widget = static_cast<QWidget*>( object );
+        auto widget = static_cast<QWidget*>( object );
 
         // check if widget can be dragged from current position
         if( isBlackListed( widget ) || !canDrag( widget ) ) return false;
 
         // retrieve widget's child at event position
-        QPoint position( mouseEvent->pos() );
-        QWidget* child = widget->childAt( position );
+        auto position( mouseEvent->pos() );
+        auto child = widget->childAt( position );
         if( !canDrag( widget, child, position ) ) return false;
 
         // save target and drag point
@@ -487,7 +485,7 @@ namespace Breeze
 
         // send a move event to the current child with same position
         // if received, it is caught to actually start the drag
-        QPoint localPoint( _dragPoint );
+        auto localPoint( _dragPoint );
         if( child ) localPoint = child->mapFrom( widget, localPoint );
         else child = widget;
         QMouseEvent localMouseEvent( QEvent::MouseMove, localPoint, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier );
@@ -508,7 +506,7 @@ namespace Breeze
         if( _dragTimer.isActive() ) _dragTimer.stop();
 
         // cast event and check drag distance
-        QMouseEvent *mouseEvent = static_cast<QMouseEvent*>( event );
+        auto mouseEvent = static_cast<QMouseEvent*>( event );
         if( !_dragInProgress )
         {
 
@@ -535,7 +533,7 @@ namespace Breeze
 
             // use QWidget::move for the grabbing
             /* this works only if the sending object and the target are identical */
-            QWidget* window( _target.data()->window() );
+            auto window( _target.data()->window() );
             window->move( window->pos() + mouseEvent->pos() - _dragPoint );
             return true;
 
@@ -582,7 +580,7 @@ namespace Breeze
         { return true; }
 
         // flat toolbuttons
-        if( QToolButton* toolButton = qobject_cast<QToolButton*>( widget ) )
+        if( auto toolButton = qobject_cast<QToolButton*>( widget ) )
         { if( toolButton->autoRaise() ) return true; }
 
         // viewports
@@ -592,10 +590,10 @@ namespace Breeze
         2/ it matches its parent viewport
         3/ the parent is not blacklisted
         */
-        if( QListView* listView = qobject_cast<QListView*>( widget->parentWidget() ) )
+        if( auto listView = qobject_cast<QListView*>( widget->parentWidget() ) )
         { if( listView->viewport() == widget && !isBlackListed( listView ) ) return true; }
 
-        if( QTreeView* treeView = qobject_cast<QTreeView*>( widget->parentWidget() ) )
+        if( auto treeView = qobject_cast<QTreeView*>( widget->parentWidget() ) )
         { if( treeView->viewport() == widget && !isBlackListed( treeView ) ) return true; }
 
         /*
@@ -603,7 +601,7 @@ namespace Breeze
         this is because of kstatusbar
         who captures buttonPress/release events
         */
-        if( QLabel* label = qobject_cast<QLabel*>( widget ) )
+        if( auto label = qobject_cast<QLabel*>( widget ) )
         {
             if( label->textInteractionFlags().testFlag( Qt::TextSelectableByMouse ) ) return false;
 
@@ -624,11 +622,11 @@ namespace Breeze
     {
 
         // check against noAnimations propery
-        QVariant propertyValue( widget->property( PropertyNames::noWindowGrab ) );
+        const auto propertyValue( widget->property( PropertyNames::noWindowGrab ) );
         if( propertyValue.isValid() && propertyValue.toBool() ) return true;
 
         // list-based blacklisted widgets
-        QString appName( qApp->applicationName() );
+        const auto appName( qApp->applicationName() );
         foreach( const ExceptionId& id, _blackList )
         {
             if( !id.appName().isEmpty() && id.appName() != appName ) continue;
@@ -649,10 +647,10 @@ namespace Breeze
     bool WindowManager::isWhiteListed( QWidget* widget ) const
     {
 
-        QString appName( qApp->applicationName() );
+        const auto appName( qApp->applicationName() );
         foreach( const ExceptionId& id, _whiteList )
         {
-            if( !id.appName().isEmpty() && id.appName() != appName ) continue;
+            if( !(id.appName().isEmpty() || id.appName() == appName ) ) continue;
             if( widget->inherits( id.className().toLatin1().data() ) ) return true;
         }
 
@@ -702,14 +700,14 @@ namespace Breeze
         { return false; }
 
         // tool buttons
-        if( QToolButton* toolButton = qobject_cast<QToolButton*>( widget ) )
+        if( auto toolButton = qobject_cast<QToolButton*>( widget ) )
         {
             if( dragMode() == StyleConfigData::WD_MINIMAL && !qobject_cast<QToolBar*>(widget->parentWidget() ) ) return false;
             return toolButton->autoRaise() && !toolButton->isEnabled();
         }
 
         // check menubar
-        if( QMenuBar* menuBar = qobject_cast<QMenuBar*>( widget ) )
+        if( auto menuBar = qobject_cast<QMenuBar*>( widget ) )
         {
 
             // do not drag from menubars embedded in Mdi windows
@@ -719,7 +717,7 @@ namespace Breeze
             if( menuBar->activeAction() && menuBar->activeAction()->isEnabled() ) return false;
 
             // check if action at position exists and is enabled
-            if( QAction* action = menuBar->actionAt( position ) )
+            if( auto action = menuBar->actionAt( position ) )
             {
                 if( action->isSeparator() ) return true;
                 if( action->isEnabled() ) return false;
@@ -743,14 +741,14 @@ namespace Breeze
         /* following checks are relevant only for WD_FULL mode */
 
         // tabbar. Make sure no tab is under the cursor
-        if( QTabBar* tabBar = qobject_cast<QTabBar*>( widget ) )
+        if( auto tabBar = qobject_cast<QTabBar*>( widget ) )
         { return tabBar->tabAt( position ) == -1; }
 
         /*
         check groupboxes
         prevent drag if unchecking grouboxes
         */
-        if( QGroupBox *groupBox = qobject_cast<QGroupBox*>( widget ) )
+        if( auto groupBox = qobject_cast<QGroupBox*>( widget ) )
         {
             // non checkable group boxes are always ok
             if( !groupBox->isCheckable() ) return true;
@@ -781,7 +779,7 @@ namespace Breeze
         }
 
         // labels
-        if( QLabel* label = qobject_cast<QLabel*>( widget ) )
+        if( auto label = qobject_cast<QLabel*>( widget ) )
         { if( label->textInteractionFlags().testFlag( Qt::TextSelectableByMouse ) ) return false; }
 
         // abstract item views
@@ -811,7 +809,7 @@ namespace Breeze
                 else if( itemView->indexAt( position ).isValid() ) return false;
             }
 
-        } else if( QGraphicsView* graphicsView =  qobject_cast<QGraphicsView*>( widget->parentWidget() ) )  {
+        } else if( auto graphicsView =  qobject_cast<QGraphicsView*>( widget->parentWidget() ) )  {
 
             if( widget == graphicsView->viewport() )
             {
@@ -828,7 +826,7 @@ namespace Breeze
     }
 
     //____________________________________________________________
-    void WindowManager::resetDrag( void )
+    void WindowManager::resetDrag()
     {
 
         if( (!useWMMoveResize() ) && _target && _cursorOverride ) {
@@ -839,9 +837,9 @@ namespace Breeze
         }
 
         _target.clear();
-#if !BREEZE_USE_KDE4
+        #if !BREEZE_USE_KDE4
         _quickTarget.clear();
-#endif
+        #endif
         if( _dragTimer.isActive() ) _dragTimer.stop();
         _dragPoint = QPoint();
         _globalDragPoint = QPoint();
@@ -861,11 +859,8 @@ namespace Breeze
         if( useWMMoveResize() )
         {
 
-            if( Helper::isX11() ) {
-                startDragX11( window, position );
-            } else if( Helper::isWayland() ) {
-                startDragWayland( window, position );
-            }
+            if( Helper::isX11() ) startDragX11( window, position );
+            else if( Helper::isWayland() ) startDragWayland( window, position );
 
         } else if( !_cursorOverride ) {
 
@@ -885,7 +880,7 @@ namespace Breeze
     {
         #if BREEZE_HAVE_X11
         // connection
-        xcb_connection_t* connection( Helper::connection() );
+        auto connection( Helper::connection() );
 
         #if QT_VERSION >= 0x050300
         const qreal dpiRatio = window->devicePixelRatio();
@@ -894,9 +889,9 @@ namespace Breeze
         #endif
 
         #if BREEZE_USE_KDE4
-        Display* net_connection = QX11Info::display();
+        auto net_connection = QX11Info::display();
         #else
-        xcb_connection_t* net_connection = connection;
+        auto net_connection = connection;
         #endif
 
         xcb_ungrab_pointer( connection, XCB_TIME_CURRENT_TIME );
@@ -922,7 +917,8 @@ namespace Breeze
         }
 
         auto shellSurface = KWayland::Client::ShellSurface::fromWindow(window);
-        if( !shellSurface ) {
+        if( !shellSurface )
+        {
             // TODO: also check for xdg-shell in future
             return;
         }
@@ -934,11 +930,12 @@ namespace Breeze
     }
 
     //____________________________________________________________
-    bool WindowManager::supportWMMoveResize( void ) const
+    bool WindowManager::supportWMMoveResize() const
     {
 
         #if BREEZE_HAVE_KWAYLAND
-        if( Helper::isWayland() ) {
+        if( Helper::isWayland() )
+        {
             return true;
         }
         #endif
@@ -956,7 +953,7 @@ namespace Breeze
     {
 
         if( !widget ) return false;
-        if( const QDockWidget* dockWidget = qobject_cast<const QDockWidget*>( widget->parent() ) )
+        if( auto dockWidget = qobject_cast<const QDockWidget*>( widget->parent() ) )
         {
 
             return widget == dockWidget->titleBarWidget();
